{
    "current_parameters": {
      "label": "",
      "elyra_filename": "",
      "elyra_runtime_image": null,
      "elyra_cpu": null,
      "elyra_gpu": null,
      "elyra_memory": null,
      "elyra_outputs": [],
      "elyra_env_vars": [],
      "elyra_kubernetes_secrets": [],
      "elyra_dependencies": [],
      "elyra_include_subdirectories": false,
      "elyra_mounted_volumes": []
    },
    "parameters": [
      {
        "id": "label"
      },
      {
        "id": "elyra_filename"
      },
      {
        "id": "elyra_runtime_image"
      },
      {
        "id": "elyra_cpu"
      },
      {
        "id": "elyra_gpu"
      },
      {
        "id": "elyra_memory"
      },
      {
        "id": "elyra_dependencies"
      },
      {
        "id": "elyra_include_subdirectories"
      },
      {
        "id": "elyra_env_vars"
      },
      {
        "id": "elyra_kubernetes_secrets"
      },
      {
        "id": "elyra_outputs"
      },
      {
        "id": "elyra_mounted_volumes"
      }
    ],
    "uihints": {
      "id": "nodeProperties",
      "parameter_info": [
        {
          "parameter_ref": "label",
          "control": "custom",
          "custom_control_id": "StringControl",
          "label": {
            "default": "Label"
          },
          "description": {
            "default": "A custom label for the node.",
            "placement": "on_panel"
          },
          "data": {}
        },
        {
          "parameter_ref": "elyra_filename",
          "control": "custom",
          "custom_control_id": "StringControl",
          "label": {
            "default": "Filename"
          },
          "description": {
            "default": "The path to the {{ component.name }}.",
            "placement": "on_panel"
          },
          "data": {
            "format": "file",
            "required": true,
            "extensions": {{ component.extensions|tojson }}
          }
        },
        {
          "parameter_ref": "elyra_runtime_image",
          "control": "custom",
          "custom_control_id": "EnumControl",
          "label": {
            "default": "Runtime Image"
          },
          "description": {
            "default": "Container image used as execution environment.",
            "placement": "on_panel"
          },
          "data": {
            "items": [],
            "required": true
          }
        },
        {
          "parameter_ref": "elyra_cpu",
          "control": "custom",
          "custom_control_id": "NumberControl",
          "label": {
            "default": "CPU"
          },
          "description": {
            "default": "For CPU-intensive workloads, you can choose more than 1 CPU (e.g. 1.5).",
            "placement": "on_panel"
          },
          "data": {
            "minimum": 0,
            "maximum": 99
          }
        },
        {
          "parameter_ref": "elyra_gpu",
          "control": "custom",
          "custom_control_id": "NumberControl",
          "label": {
            "default": "GPU"
          },
          "description": {
            "default": "For GPU-intensive workloads, you can choose more than 1 GPU. Must be an integer.",
            "placement": "on_panel"
          },
          "data": {
            "minimum": 0,
            "maximum": 99
          }
        },
        {
          "parameter_ref": "elyra_memory",
          "control": "custom",
          "custom_control_id": "NumberControl",
          "label": {
            "default": "RAM(GB)"
          },
          "description": {
            "default": "The total amount of RAM specified.",
            "placement": "on_panel"
          },
          "data": {
            "minimum": 0,
            "maximum": 99
          }
        },
        {
          "parameter_ref": "elyra_dependencies",
          "control": "custom",
          "custom_control_id": "StringArrayControl",
          "label": {
            "default": "File Dependencies"
          },
          "description": {
            "default": "Local file dependencies that need to be copied to remote execution environment.",
            "placement": "on_panel"
          },
          "data": {
            "placeholder": "*.py",
            "format": "file"
          }
        },
        {
          "parameter_ref": "elyra_include_subdirectories",
          "control": "custom",
          "custom_control_id": "BooleanControl",
          "label": {
            "default": "Include Subdirectories",
            "placement": "on_panel"
          },
          "data": {
            "description": "Recursively include subdirectories when submitting a pipeline (This may increase submission time)."
          }
        },
        {
          "parameter_ref": "elyra_env_vars",
          "control": "custom",
          "custom_control_id": "StringArrayControl",
          "label": {
            "default": "Environment Variables"
          },
          "description": {
            "default": "Environment variables to be set on the execution environment.",
            "placement": "on_panel"
          },
          "data": {
            "placeholder": "env_var=VALUE",
            "canRefresh": true,
            "keyValueEntries": true
          }
        },
        {
          "parameter_ref": "elyra_kubernetes_secrets",
          "control": "custom",
          "custom_control_id": "StringArrayControl",
          "label": {
            "default": "Kubernetes Secrets"
          },
          "description": {
            "default": "Kubernetes secrets to make available as environment variables to this node. The secret name and key given must be present in the Kubernetes namespace where the node is executed or this node will not run.",
            "placement": "on_panel"
          },
          "data": {
            "placeholder": "env_var=secret-name:secret-key",
            "keyValueEntries": true
          }
        },
        {
          "parameter_ref": "elyra_outputs",
          "control": "custom",
          "custom_control_id": "StringArrayControl",
          "label": {
            "default": "Output Files"
          },
          "description": {
            "default": "Files generated during execution that will become available to all subsequent pipeline steps.",
            "placement": "on_panel"
          },
          "data": {
            "placeholder": "*.csv"
          }
        },
        {
          "parameter_ref": "elyra_mounted_volumes",
          "control": "custom",
          "custom_control_id": "StringArrayControl",
          "label": {
            "default": "Data Volumes"
          },
          "description": {
           "default": "Volumes to be mounted in this node. The specified Persistent Volume Claims must exist in the Kubernetes namespace where the node is executed or this node will not run.",
           "placement": "on_panel"
          },
          "data": {
            "placeholder": "/mount/path=pvc-name",
            "keyValueEntries": true
          }
        }
      ],
      "group_info": [
        {
          "id": "nodeGroupInfo",
          "type": "panels",
          "group_info": [
            {
              "id": "label",
              "type": "controls",
              "parameter_refs": ["label"]
            },
            {
              "id": "elyra_filename",
              "type": "controls",
              "parameter_refs": ["elyra_filename"]
            },
            {
              "id": "elyra_runtime_image",
              "type": "controls",
              "parameter_refs": ["elyra_runtime_image"]
            },
            {
              "id": "elyra_resources",
              "type": "controls",
              "parameter_refs": ["elyra_cpu", "elyra_gpu", "elyra_memory"]
            },
            {
              "id": "elyra_dependencies",
              "type": "controls",
              "parameter_refs": ["elyra_dependencies"]
            },
            {
              "id": "elyra_include_subdirectories",
              "type": "controls",
              "parameter_refs": ["elyra_include_subdirectories"]
            },
            {
              "id": "elyra_env_vars",
              "type": "controls",
              "parameter_refs": ["elyra_env_vars"]
            },
            {
              "id": "elyra_kubernetes_secrets",
              "type": "controls",
              "parameter_refs": ["elyra_kubernetes_secrets"]
            },
            {
              "id": "elyra_outputs",
              "type": "controls",
              "parameter_refs": ["elyra_outputs"]
            },
            {
              "id": "elyra_mounted_volumes",
              "type": "controls",
              "parameter_refs": ["elyra_mounted_volumes"]
            }
          ]
        }
      ]
    },
    "resources": {}
  }
