"use strict";
(self["webpackChunk_elyra_pipeline_editor_extension"] = self["webpackChunk_elyra_pipeline_editor_extension"] || []).push([["style_index_css"],{

/***/ "../../node_modules/css-loader/dist/cjs.js!./style/index.css":
/*!*******************************************************************!*\
  !*** ../../node_modules/css-loader/dist/cjs.js!./style/index.css ***!
  \*******************************************************************/
/***/ ((module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _node_modules_css_loader_dist_runtime_cssWithMappingToString_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../../node_modules/css-loader/dist/runtime/cssWithMappingToString.js */ "../../node_modules/css-loader/dist/runtime/cssWithMappingToString.js");
/* harmony import */ var _node_modules_css_loader_dist_runtime_cssWithMappingToString_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_node_modules_css_loader_dist_runtime_cssWithMappingToString_js__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../../node_modules/css-loader/dist/runtime/api.js */ "../../node_modules/css-loader/dist/runtime/api.js");
/* harmony import */ var _node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1__);
// Imports


var ___CSS_LOADER_EXPORT___ = _node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1___default()((_node_modules_css_loader_dist_runtime_cssWithMappingToString_js__WEBPACK_IMPORTED_MODULE_0___default()));
// Module
___CSS_LOADER_EXPORT___.push([module.id, "/*\n * Copyright 2018-2022 Elyra Authors\n *\n * Licensed under the Apache License, Version 2.0 (the \"License\");\n * you may not use this file except in compliance with the License.\n * You may obtain a copy of the License at\n *\n * http://www.apache.org/licenses/LICENSE-2.0\n *\n * Unless required by applicable law or agreed to in writing, software\n * distributed under the License is distributed on an \"AS IS\" BASIS,\n * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n * See the License for the specific language governing permissions and\n * limitations under the License.\n */\n\nbody {\n  --elyra-border-radius: 0;\n  --elyra-color-icon: var(--jp-icon-contrast-color3);\n  --elyra-color-panel-bg: var(--jp-layout-color1);\n  --elyra-color-panel-border: var(--jp-border-color0);\n\n  --elyra-color-focus: var(--jp-border-color1);\n\n  --elyra-color-text-primary: var(--jp-ui-font-color0);\n\n  --elyra-color-button-text: var(--jp-ui-font-color0);\n  --elyra-color-button-bg: var(--jp-input-active-background);\n  --elyra-color-button-hover-bg: var(--jp-input-hover-background);\n\n  /* ======================================================================== */\n  /* PIPELINE */\n  /* ======================================================================== */\n\n  /* comment */\n  --elyra-color-comment-text: var(--jp-ui-font-color0);\n  --elyra-color-comment-link: var(--jp-border-color1);\n  --elyra-color-comment-bg: var(--jp-editor-selected-background);\n  --elyra-color-comment-border: var(--jp-border-color1);\n\n  /* node */\n  --elyra-color-node-text: var(--jp-ui-font-color0);\n  --elyra-color-node-link: var(--jp-content-link-color);\n  --elyra-color-node-bg: var(--jp-cell-editor-active-background);\n  --elyra-color-node-border: transparent;\n  --elyra-color-node-hover-bg: var(--jp-input-hover-background);\n  --elyra-color-node-hover-border: transparent;\n\n  /* errors */\n  --elyra-color-text-error: var(--jp-rendermime-error-background);\n  --elyra-color-error-border: var(--jp-error-color0);\n\n  /* tooltip */\n  --elyra-color-tooltip-text: var(--jp-content-font-color0);\n  --elyra-color-tooltip-text-bold: var(--jp-editor-selected-background);\n  --elyra-color-tooltip-bg: var(--jp-cell-editor-active-background);\n  --elyra-color-tooltip-border: var(--jp-border-color1);\n\n  /* ======================================================================== */\n  /* FORM */\n  /* ======================================================================== */\n\n  --elyra-color-formLabel-text: var(--jp-content-font-color0);\n  --elyra-color-formDescription-text: var(--jp-content-font-color0);\n\n  /* text input */\n  --elyra-color-textInput-text: var(--jp-content-font-color0);\n  --elyra-color-textInput-bg: var(--jp-cell-editor-active-background);\n  --elyra-color-textInput-border: var(--jp-border-color1);\n  --elyra-color-textInput-disabled-text: var(--jp-inverse-layout-color4);\n\n  /* array input */\n  --elyra-color-arrayInput-text: var(--jp-content-font-color0);\n  --elyra-color-arrayInput-bg: var(--jp-cell-editor-active-background);\n  --elyra-color-arrayInput-border: var(--jp-border-color1);\n\n  /* dropdown */\n  --elyra-color-dropdown-text: var(--jp-content-font-color0);\n  --elyra-color-dropdown-bg: var(--jp-cell-editor-active-background);\n  --elyra-color-dropdown-border: var(--jp-border-color1);\n  --elyra-color-dropdownItem-hover-bg: var(--jp-input-hover-background);\n\n  /* checkbox */\n  --elyra-color-checkbox-text: var(--jp-content-font-color0);\n  --elyra-color-checkbox-bg: var(--jp-cell-editor-active-background);\n  --elyra-color-checkbox-border: var(--jp-border-color1);\n\n  /* primary button */\n  --elyra-color-formButton-text: var(--jp-ui-font-color0);\n  --elyra-color-formButton-bg: var(--jp-layout-color3);\n  --elyra-color-formButton-border: transparent;\n  --elyra-color-formButton-hover-bg: var(--jp-content-font-color3);\n  --elyra-color-formButton-hover-border: transparent;\n\n  /* ======================================================================== */\n  /* PALETTE */\n  /* ======================================================================== */\n  --elyra-color-palette-text: var(--jp-ui-font-color0);\n  --elyra-color-palette-bg: var(--jp-cell-editor-active-background);\n  --elyra-color-palette-border: transparent;\n\n  /* ======================================================================== */\n  /* FONTS */\n  /* ======================================================================== */\n\n  /* sans */\n  --elyra-font-family-sans: var(--jp-ui-font-family);\n  --elyra-font-weight-sans: normal;\n  --elyra-font-size-sans: var(--jp-code-font-size);\n\n  /* mono */\n  --elyra-font-family-mono: var(--jp-ui-font-family);\n  --elyra-font-weight-mono: normal;\n  --elyra-font-size-mono: var(--jp-code-font-size);\n}\n\nbody {\n  background-color: var(--jp-editor-selected-background);\n}\n\n.elyra-empty-text {\n  color: rgba(0, 0, 0, 0.68);\n  cursor: default;\n  font-family: -apple-system, system-ui, sans-serif;\n  font-size: 13px;\n  height: 19px;\n  letter-spacing: 0.52px;\n  line-height: 18.2px;\n  user-select: none;\n}\n\n.elyra-empty-image {\n  opacity: 0.05;\n  margin-bottom: 50px;\n}\n\n.properties-control-panel[data-id='properties-nodeGroupInfo']\n  > .properties-control-panel\n  > .properties-control-item {\n  position: relative;\n}\n\n.properties-control-panel[data-id='properties-nodeGroupInfo']\n  > .properties-control-panel\n  > .properties-control-item\n  .error::before {\n  display: block;\n  content: ' ';\n  position: absolute;\n  width: 6px;\n  border-left-width: 2px;\n  border-left-style: solid;\n  left: 5px;\n  top: 15px;\n  bottom: 18px;\n  border-color: var(--elyra-color-error-border);\n}\n\n.elyra-stringArrayControl-inputWrapper {\n  height: 35px;\n}\n\n.elyra-PipelineEditor .elyra-stringArrayControl-input {\n  width: 100%;\n  height: 100%;\n  margin-bottom: 5px;\n}\n\n.properties-input-control.error input:not([disabled]) {\n  box-shadow: none;\n}\n\nspan.bx--list-box__label {\n  color: var(--elyra-color-formLabel-text);\n}\n\n.properties-dropdown.error .bx--list-box__field:not([disabled]) {\n  box-shadow: none;\n}\n\n.elyra-PipelineEditor .properties-wrapper .bx--list-box__field {\n  height: 100%;\n}\n\n.elyra-PipelineEditor .properties-wrapper input[type='text']:disabled {\n  height: 39px;\n  padding-left: 8px;\n}\n\n.properties-dropdown .bx--list-box--expanded .bx--list-box__menu {\n  top: auto;\n}\n\n.properties-wrapper .bx--list-box__menu-item {\n  display: contents;\n}\n\n.properties-required-indicator {\n  display: none;\n}\n\n.properties-control-panel[data-id='properties-elyra_resources']\n  .properties-custom-ctrl {\n  position: absolute;\n  bottom: 18px;\n  padding-right: 14px;\n}\n\n.properties-control-panel[data-id='properties-elyra_resources']\n  .properties-control-description {\n  padding-bottom: 35px;\n}\n\n.elyra-stringArrayControl-listItem {\n  padding: 5px;\n}\n\n.elyra-stringArrayControl-listRow:hover {\n  position: relative;\n  background-color: var(--jp-border-color2);\n}\n\n/* ======================================================== */\n/* ======================================================== */\n/* ======================================================== */\n\n.properties-control-panel[data-id='properties-nodeGroupInfo']\n  > .properties-control-panel\n  > .properties-control-item {\n  position: relative;\n}\n\n.properties-control-panel[data-id='properties-nodeGroupInfo']\n  > .properties-control-panel\n  > .properties-control-item:hover {\n  background-color: var(--jp-cell-editor-background);\n}\n\n.properties-control-panel[data-id='properties-nodeGroupInfo']\n  > .properties-control-panel\n  > .properties-control-item.selected {\n  background-color: var(--jp-editor-selected-focused-background);\n}\n\n.properties-control-panel[data-id='properties-nodeGroupInfo']\n  > .properties-control-panel\n  > .properties-control-item.selected::before {\n  content: '';\n  position: absolute;\n  top: 0;\n  left: 0;\n  right: 0;\n  border-top: 1px solid var(--jp-border-color2);\n}\n\n.elyra-stringArrayControl-listRow {\n  background-color: var(--jp-border-color3);\n  margin-bottom: 5px;\n}\n\n.properties-control-panel[data-id='properties-nodeGroupInfo']\n  > .properties-control-panel\n  > .properties-control-item.selected::after {\n  content: '';\n  position: absolute;\n  bottom: 0;\n  left: 0;\n  right: 0;\n  border-top: 1px solid var(--jp-border-color2);\n}\n\n.elyra-resourcesWrapper {\n  display: flex;\n  flex-direction: row;\n  position: relative;\n  height: 110px;\n}\n\n.elyra-resourceInput {\n  width: 22%;\n  display: flex;\n  flex-direction: column;\n  padding-right: 9px;\n}\n/* ======================================================== */\n/* ======================================================== */\n/* ======================================================== */\n\n.d3-node-port-input,\n.d3-node-port-output,\n.d3-node-port-input[connected='yes'],\n.d3-node-port-output[connected='yes'] {\n  stroke: var(--elyra-color-comment-text);\n  fill: var(--elyra-color-comment-text);\n  stroke-width: 4;\n}\n\n.d3-node-port-input:hover,\n.d3-node-port-output:hover,\n.d3-node-port-input[connected='yes']:hover,\n.d3-node-port-output[connected='yes']:hover {\n  stroke: var(--elyra-color-node-text);\n  fill: var(--elyra-color-node-text);\n  stroke-width: 4;\n}\n\n.d3-node-port-input-arrow {\n  display: none;\n}\n\n.elyra-PipelineEditor .palette-flyout-div,\n.elyra-PipelineEditor\n  .palette-flyout-search-container\n  .palette-flyout-search\n  input {\n  background-color: var(--jp-layout-color1);\n  color: var(--jp-content-font-color1);\n}\n\n.elyra-PipelineEditor .palette-flyout-div {\n  border-right: 1px solid var(--jp-layout-color3);\n}\n\n.elyra-PipelineEditor .palette-flyout-content .palette-list-item:hover {\n  background-color: var(--jp-border-color1);\n}\n\n.elyra-PipelineEditor .bx--search-magnifier {\n  stroke: var(--jp-inverse-layout-color1);\n}\n\n.elyra-PipelineEditor svg.palette-flyout-category-caret,\n.elyra-PipelineEditor .palette-flyout-category-item-icon {\n  background: none;\n  fill: var(--jp-inverse-layout-color1);\n}\n\n.tip-palette-item,\n.tip-palette-category,\n.tip-palette-label,\n.tip-palette-desc {\n  color: var(--elyra-color-tooltip-text) !important;\n}\n\n.elyra-PipelineEditor\n  .palette-flyout-category\n  .elyra-PipelineEditor\n  .palette-content-list {\n  border-bottom: 1px solid var(--jp-content-font-color0);\n}\n\n/* tabs */\n.elyra-tabPanel > .elyra-actionBar {\n  padding: 0 8px;\n}\n\n.elyra-tab {\n  cursor: pointer;\n  user-select: none;\n  text-transform: uppercase;\n  padding: 4px 10px 3px;\n}\n\n.elyra-tabText {\n  line-height: 27px;\n  font-family: var(--elyra-font-family-sans);\n  font-size: 11px;\n  font-weight: var(--elyra-font-weight-sans);\n  color: var(--jp-border-color1);\n}\n\n.elyra-tabText:hover {\n  color: var(--jp-ui-font-color0);\n}\n\n.elyra-tabText.activeTab {\n  color: var(--jp-ui-font-color0);\n  border-bottom: 1px solid var(--jp-border-color2);\n}\n\n.elyra-icon {\n  font: normal normal normal 16px/1 codicon;\n  font-size: 16px;\n  text-decoration: none;\n  text-rendering: auto;\n  text-align: center;\n  -webkit-font-smoothing: antialiased;\n}\n\n.elyra-actionItem {\n  cursor: pointer;\n  user-select: none;\n  display: inline-block;\n  transition: transform 50ms ease;\n  position: relative;\n  padding: 3px;\n}\n\n.elyra-actionItem:active {\n  transform: scale(1.272019649);\n}\n\n.elyra-verticalTabGroup .elyra-tabItem {\n  margin: 3px 0;\n}\n\n.elyra-verticalTabGroup .elyra-tabItem:hover {\n  background-color: var(--jp-cell-editor-background);\n}\n\n.elyra-verticalTabGroup .elyra-tabItem:active {\n  background-color: rgba(255, 255, 255, 0.18);\n}\n\n.elyra-actionBar .elyra-actionItemIcon {\n  color: var(--elyra-color-arrayInput-text);\n  display: block;\n  height: 35px;\n  line-height: 35px;\n  min-width: 28px;\n  margin-right: 4px;\n}\n\n.elyra-stringArrayControl-listRow:hover .elyra-stringArrayControl-listActions {\n  height: 100%;\n  align-items: center;\n  margin-right: 3px;\n}\n\n.elyra-actionItem:hover {\n  background-color: var(--jp-border-color1);\n}\n\n.elyra-stringArrayControl-listActions .elyra-actionItemIcon {\n  color: var(--elyra-color-arrayInput-text);\n  width: 16px;\n  height: 20px;\n  padding: 2px;\n  margin-right: 2px;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  background-position: center;\n}\n\n.elyra-tabItemIcon {\n  cursor: pointer;\n  user-select: none;\n  color: var(--elyra-color-arrayInput-text);\n  display: inline-block;\n  height: 35px;\n  line-height: 35px;\n  min-width: 28px;\n  margin-right: 4px;\n}\n\n.elyra-icon {\n  background-repeat: no-repeat;\n}\n\n.elyra-icon.elyra-item-delete {\n  background-image: url('data:image/svg+xml;utf8,<svg focusable=\"false\" preserveAspectRatio=\"xMidYMid meet\" xmlns=\"http://www.w3.org/2000/svg\" width=\"15\" height=\"32\" viewBox=\"0 0 32 32\"> <title>Delete item</title> <g class=\"jp-icon3\"> <path d=\"M12 12H14V24H12zM18 12H20V24H18z\"></path> <path d=\"M4 6V8H6V28a2 2 0 002 2H24a2 2 0 002-2V8h2V6zM8 28V8H24V28zM12 2H20V4H12z\"></path> </g> </svg>');\n}\n\n.elyra-icon.elyra-item-edit {\n  background-image: url('data:image/svg+xml;utf8,<svg viewBox=\"0 0 24 24\" width=\"16\" xmlns=\"http://www.w3.org/2000/svg\"> <g class=\"jp-icon3\"> <path d=\"M3 17.25V21h3.75L17.81 9.94l-3.75-3.75L3 17.25zM20.71 7.04c.39-.39.39-1.02 0-1.41l-2.34-2.34c-.39-.39-1.02-.39-1.41 0l-1.83 1.83 3.75 3.75 1.83-1.83z\"/> </g> </svg>');\n}\n\n.elyra-icon.elyra-panel-close::before {\n  content: '';\n}\n\n.elyra-icon.properties::before {\n  content: '';\n}\n\n.elyra-icon.palette::before {\n  content: '\\eb5c';\n}\n\n.elyra-icon.properties-checkbox {\n  background-image: url('data:image/svg+xml;utf8,<svg viewBox=\"0 0 24 24\" width=\"16\" xmlns=\"http://www.w3.org/2000/svg\"> <g class=\"jp-icon-none jp-icon-selectable-inverse jp-icon3-hover\" fill=\"none\"> <circle cx=\"12\" cy=\"12\" r=\"11\"/></g><g class=\"jp-icon3 jp-icon-selectable jp-icon-accent2-hover\" fill=\"#616161\"><path d=\"M19 6.41L17.59 5 12 10.59 6.41 5 5 6.41 10.59 12 5 17.59 6.41 19 12 13.41 17.59 19 19 17.59 13.41 12z\"/></g><g class=\"jp-icon-none jp-icon-busy\" fill=\"none\"><circle cx=\"12\" cy=\"12\" r=\"7\"/></g></svg>');\n}\n\n.elyra-icon.elyra-item-folder {\n  background-image: url('data:image/svg+xml;utf8,<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 24 24\"> <path class=\"jp-icon3 jp-icon-selectable\" d=\"M10 4H4c-1.1 0-1.99.9-1.99 2L2 18c0 1.1.9 2 2 2h16c1.1 0 2-.9 2-2V8c0-1.1-.9-2-2-2h-8l-2-2z\"/> </svg>');\n}\n\n.elyra-stringArrayActions {\n  height: 100%;\n  align-items: center;\n}\n\n.elyra-inputContainer {\n  width: 100%;\n}\n\n.elyra-listRow {\n  margin-bottom: 3px;\n}\n\n.elyra-loader {\n  display: block;\n  position: absolute;\n  left: -200px;\n  width: 200px;\n  height: 4px;\n  border-radius: 4px;\n  background-color: var(--jp-brand-color1);\n  animation: loading 2s linear infinite;\n}\n\n/* context menu */\n\n.d3-node-ellipsis-group {\n  display: none;\n}\n\n.context-menu-popover {\n  margin-top: -6px;\n  margin-left: 2px;\n  padding: 6px 0;\n  backdrop-filter: saturate(180%) blur(20px);\n  border-radius: 6px;\n  /* box-shadow: 0px 4px 17.64px 3.36px rgba(0, 0, 0, 0.2); */\n  user-select: none;\n  cursor: default;\n  /* box-shadow: 0px 2px 4px 0px rgba(0, 0, 0, 0.05),\n    0px 8px 15px 2px rgba(0, 0, 0, 0.18); */\n  box-shadow: 0px 1px 2px 0px rgba(0, 0, 0, 0.05),\n    0px 4px 15px 2px rgba(0, 0, 0, 0.18);\n}\n\n.context-menu-popover::before {\n  position: absolute;\n  top: 0;\n  left: 0;\n  width: 200%;\n  height: 200%;\n  border-radius: 13px;\n  content: '';\n  transform: scale(0.5);\n  -webkit-transform: scale(0.5);\n  transform-origin: 0 0;\n  -webkit-transform-origin: 0 0;\n}\n\n.react-contextmenu-item {\n  position: relative;\n  margin: 0 6px;\n  width: auto;\n  height: 22px;\n  border-radius: 4px;\n  font-size: 13px;\n  padding: 3px 9px;\n  box-sizing: border-box;\n  cursor: default;\n  z-index: 0;\n}\n\n.react-contextmenu-item:hover::before {\n  content: '';\n\n  /* rgba(10, 130, 255, 0.75); */\n  background-color: rgba(54, 131, 247, 0.75);\n  backdrop-filter: saturate(0%);\n  position: absolute;\n  top: 0;\n  left: 0;\n  right: 0;\n  bottom: 0;\n  border-radius: 4px;\n  z-index: -1;\n}\n\n.react-contextmenu-item:hover::after {\n  content: '';\n  background: var(--elyra-color-panel-bg);\n  position: absolute;\n  top: 0;\n  left: 0;\n  right: 0;\n  bottom: 0;\n  border-radius: 4px;\n  z-index: -2;\n}\n\n.react-contextmenu-item.contextmenu-divider {\n  margin: 5px 15px;\n}\n\n.react-contextmenu-item.react-contextmenu-item--disabled {\n  cursor: default;\n  opacity: 1;\n}\n\n.react-contextmenu-item:active,\n.react-contextmenu-item:focus,\n.react-contextmenu-item.react-contextmenu-item--disabled {\n  background: transparent !important;\n}\n\n.react-contextmenu-item.react-contextmenu-item--disabled::before,\n.react-contextmenu-item.react-contextmenu-item--disabled::after {\n  display: none !important;\n}\n\n/* ========================================================================== */\n/* LIGHT THEME */\n/* ========================================================================== */\n.context-menu-popover {\n  background: rgba(231, 231, 231, 0.76);\n}\n\n.context-menu-popover::before {\n  /* box-shadow: inset 0px 0px 0px 1px rgba(0, 0, 0, 0.22),\n    inset 0px 0px 0px 2px rgba(255, 255, 255, 0.1); */\n  box-shadow: 0px 0px 0px 1px rgba(0, 0, 0, 0.22),\n    inset 0px 0px 0px 1px rgba(255, 255, 255, 0.1);\n}\n\n.react-contextmenu-item {\n  color: rgba(0, 0, 0, 0.85);\n}\n\n.react-contextmenu-item:hover {\n  color: rgba(255, 255, 255, 1);\n}\n\n.react-contextmenu-item.react-contextmenu-item--disabled {\n  color: rgba(0, 0, 0, 0.315); /* 0.27, 0.36 */\n}\n\n.react-contextmenu-item.contextmenu-divider {\n  background-color: #000000;\n  opacity: 0.13; /* 0.11, 0.15 */\n}\n\n/* ========================================================================== */\n/* DARK THEME */\n/* ========================================================================== */\n\nbody.elyra-dark .context-menu-popover {\n  background: rgba(46, 46, 46, 0.72);\n}\n\nbody.elyra-dark .context-menu-popover::before {\n  box-shadow: inset 0px 0px 0px 1px rgba(0, 0, 0, 0.86),\n    inset 0px 0px 0px 3px rgba(255, 255, 255, 0.2);\n}\n\nbody.elyra-dark .react-contextmenu-item {\n  color: rgba(255, 255, 255, 0.9);\n}\n\nbody.elyra-dark .react-contextmenu-item:hover {\n  color: rgba(255, 255, 255, 0.9);\n}\n\nbody.elyra-dark .react-contextmenu-item.react-contextmenu-item--disabled {\n  color: rgba(255, 255, 255, 0.355); /* 0.29, 0.42 */\n}\n\nbody.elyra-dark .react-contextmenu-item.contextmenu-divider {\n  background-color: #ffffff;\n  opacity: 0.205; /* 0.17, 0.24 */\n}\n\ninput.elyra-Dialog-checkbox.jp-mod-styled {\n  appearance: auto;\n  -moz-appearance: checkbox;\n  -webkit-appearance: checkbox;\n  height: auto;\n}\n\n.elyra-dialog-form {\n  max-width: 700px;\n}\n\n.elyra-dialog-form input[type='text'] {\n  width: 100%;\n}\n\n.elyra-dialog-form input,\n.elyra-dialog-form select.jp-mod-styled {\n  border-radius: 4px;\n}\n\n.elyra-resourceInputDescription {\n  padding-top: 4px;\n  padding-bottom: 4px;\n}\n\n#cpu,\n#gpu,\n#memory {\n  position: absolute;\n  vertical-align: baseline;\n  bottom: 0;\n  width: 20%;\n}\n\n/* fix a Safari bug where button margins default to 2px */\n.properties-control-panel button {\n  margin: 0;\n}\n\n.toolbar-item-content .toolbar-icon svg {\n  background: var(--jp-border-color2);\n}\n\n.elyra-PipelineEditor .toolbar-item.default button:disabled:hover svg,\n.toolbar-item.ghost button:disabled:hover svg,\n.toolbar-overflow-menu-item button:disabled:hover svg {\n  background-color: var(--jp-border-color2);\n}\n\n.elyra-PipelineEditor .toolbar-item.default button:hover svg,\n.toolbar-item.ghost button:hover svg,\n.toolbar-overflow-item button:hover svg,\n.toolbar-overflow-menu-item button:hover svg {\n  background: var(--jp-border-color1);\n}\n\n.properties-control-panel[data-id='properties-elyra_resources'] {\n  display: flex;\n}\n\n.properties-control-panel[data-id='properties-elyra_resources']\n  .properties-ctrl-wrapper {\n  width: 33%;\n}\n\n.elyra-PipelineEditor .toolbar-item.default button:hover,\n.toolbar-item.ghost button:hover,\n.toolbar-overflow-item button:hover,\n.toolbar-overflow-menu-item button:hover {\n  background-color: var(--jp-border-color1);\n}\n\n.properties-custom-ctrl div[data-testid='list-row'] {\n  background-color: var(--jp-border-color1);\n  padding: 3px;\n}\n\n.properties-control-item[data-id='properties-ci-runtime_image']\n  ul[role='listbox'] {\n  max-height: 120px;\n  overflow-y: scroll;\n}\n\n.properties-control-item[data-id='properties-ci-runtime_image']\n  ul[role='listbox']::-webkit-scrollbar {\n  width: 10px;\n}\n\n.properties-control-item[data-id='properties-ci-runtime_image']\n  ul[role='listbox']::-webkit-scrollbar-thumb {\n  background-color: var(--jp-border-color1);\n}\n\n.properties-control-item[data-id='properties-ci-runtime_image']\n  ul[role='listbox']::-webkit-scrollbar-thumb:hover {\n  background-color: var(--jp-border-color0);\n}\n\n.properties-control-item[data-id='properties-ci-runtime_image']\n  ul[role='listbox']\n  li {\n  height: 22px;\n  display: flex;\n  align-items: center;\n  margin-left: 5px;\n}\n\n.elyra-PipelineEditor .toolbar-item.tertiary button:disabled,\n.elyra-PipelineEditor .toolbar-item.tertiary button:disabled:hover {\n  background-color: var(--jp-border-color2);\n  color: var(--jp-content-font-color1);\n  border: none;\n  cursor: initial;\n}\n\n.elyra-PipelineEditor .elyra_categoryHeader {\n  padding-left: 33px;\n  padding-right: 24px;\n}\n\n.elyra-PipelineEditor .elyra_categoryHeader .panel-label {\n  font-size: var(--jp-content-font-size2);\n}\n\n.elyra-PipelineEditor-Alert {\n  white-space: pre-line;\n}\n\n/* fix font ligatures */\n.lsp-completer-theme-vscode {\n  letter-spacing: normal;\n}\n\na {\n  pointer-events: auto;\n  cursor: pointer;\n}\n\n.empty-pipeline-header {\n  color: #8897a2;\n  text-align: center;\n}\n\nh3.empty-pipeline-header {\n  font-size: var(--jp-content-font-size5);\n}\n\nh4.empty-pipeline-header {\n  font-size: var(--jp-content-font-size3);\n}\n\n.empty-pipeline-icon {\n  display: inline-block;\n  vertical-align: middle;\n}\n\n.empty-pipeline-button {\n  display: inline-block;\n  vertical-align: middle;\n  pointer-events: auto;\n  cursor: pointer;\n  padding: 0;\n  border: none;\n  background: none;\n  color: var(--jp-brand-color1);\n}\n\n.empty-pipeline-button:hover {\n  background-color: var(--jp-layout-color2);\n  cursor: pointer;\n}\n\n.empty-pipeline-button .jp-icon3[fill] {\n  fill: var(--jp-brand-color1);\n}\n", "",{"version":3,"sources":["webpack://./style/index.css"],"names":[],"mappings":"AAAA;;;;;;;;;;;;;;EAcE;;AAEF;EACE,wBAAwB;EACxB,kDAAkD;EAClD,+CAA+C;EAC/C,mDAAmD;;EAEnD,4CAA4C;;EAE5C,oDAAoD;;EAEpD,mDAAmD;EACnD,0DAA0D;EAC1D,+DAA+D;;EAE/D,6EAA6E;EAC7E,aAAa;EACb,6EAA6E;;EAE7E,YAAY;EACZ,oDAAoD;EACpD,mDAAmD;EACnD,8DAA8D;EAC9D,qDAAqD;;EAErD,SAAS;EACT,iDAAiD;EACjD,qDAAqD;EACrD,8DAA8D;EAC9D,sCAAsC;EACtC,6DAA6D;EAC7D,4CAA4C;;EAE5C,WAAW;EACX,+DAA+D;EAC/D,kDAAkD;;EAElD,YAAY;EACZ,yDAAyD;EACzD,qEAAqE;EACrE,iEAAiE;EACjE,qDAAqD;;EAErD,6EAA6E;EAC7E,SAAS;EACT,6EAA6E;;EAE7E,2DAA2D;EAC3D,iEAAiE;;EAEjE,eAAe;EACf,2DAA2D;EAC3D,mEAAmE;EACnE,uDAAuD;EACvD,sEAAsE;;EAEtE,gBAAgB;EAChB,4DAA4D;EAC5D,oEAAoE;EACpE,wDAAwD;;EAExD,aAAa;EACb,0DAA0D;EAC1D,kEAAkE;EAClE,sDAAsD;EACtD,qEAAqE;;EAErE,aAAa;EACb,0DAA0D;EAC1D,kEAAkE;EAClE,sDAAsD;;EAEtD,mBAAmB;EACnB,uDAAuD;EACvD,oDAAoD;EACpD,4CAA4C;EAC5C,gEAAgE;EAChE,kDAAkD;;EAElD,6EAA6E;EAC7E,YAAY;EACZ,6EAA6E;EAC7E,oDAAoD;EACpD,iEAAiE;EACjE,yCAAyC;;EAEzC,6EAA6E;EAC7E,UAAU;EACV,6EAA6E;;EAE7E,SAAS;EACT,kDAAkD;EAClD,gCAAgC;EAChC,gDAAgD;;EAEhD,SAAS;EACT,kDAAkD;EAClD,gCAAgC;EAChC,gDAAgD;AAClD;;AAEA;EACE,sDAAsD;AACxD;;AAEA;EACE,0BAA0B;EAC1B,eAAe;EACf,iDAAiD;EACjD,eAAe;EACf,YAAY;EACZ,sBAAsB;EACtB,mBAAmB;EACnB,iBAAiB;AACnB;;AAEA;EACE,aAAa;EACb,mBAAmB;AACrB;;AAEA;;;EAGE,kBAAkB;AACpB;;AAEA;;;;EAIE,cAAc;EACd,YAAY;EACZ,kBAAkB;EAClB,UAAU;EACV,sBAAsB;EACtB,wBAAwB;EACxB,SAAS;EACT,SAAS;EACT,YAAY;EACZ,6CAA6C;AAC/C;;AAEA;EACE,YAAY;AACd;;AAEA;EACE,WAAW;EACX,YAAY;EACZ,kBAAkB;AACpB;;AAEA;EACE,gBAAgB;AAClB;;AAEA;EACE,wCAAwC;AAC1C;;AAEA;EACE,gBAAgB;AAClB;;AAEA;EACE,YAAY;AACd;;AAEA;EACE,YAAY;EACZ,iBAAiB;AACnB;;AAEA;EACE,SAAS;AACX;;AAEA;EACE,iBAAiB;AACnB;;AAEA;EACE,aAAa;AACf;;AAEA;;EAEE,kBAAkB;EAClB,YAAY;EACZ,mBAAmB;AACrB;;AAEA;;EAEE,oBAAoB;AACtB;;AAEA;EACE,YAAY;AACd;;AAEA;EACE,kBAAkB;EAClB,yCAAyC;AAC3C;;AAEA,6DAA6D;AAC7D,6DAA6D;AAC7D,6DAA6D;;AAE7D;;;EAGE,kBAAkB;AACpB;;AAEA;;;EAGE,kDAAkD;AACpD;;AAEA;;;EAGE,8DAA8D;AAChE;;AAEA;;;EAGE,WAAW;EACX,kBAAkB;EAClB,MAAM;EACN,OAAO;EACP,QAAQ;EACR,6CAA6C;AAC/C;;AAEA;EACE,yCAAyC;EACzC,kBAAkB;AACpB;;AAEA;;;EAGE,WAAW;EACX,kBAAkB;EAClB,SAAS;EACT,OAAO;EACP,QAAQ;EACR,6CAA6C;AAC/C;;AAEA;EACE,aAAa;EACb,mBAAmB;EACnB,kBAAkB;EAClB,aAAa;AACf;;AAEA;EACE,UAAU;EACV,aAAa;EACb,sBAAsB;EACtB,kBAAkB;AACpB;AACA,6DAA6D;AAC7D,6DAA6D;AAC7D,6DAA6D;;AAE7D;;;;EAIE,uCAAuC;EACvC,qCAAqC;EACrC,eAAe;AACjB;;AAEA;;;;EAIE,oCAAoC;EACpC,kCAAkC;EAClC,eAAe;AACjB;;AAEA;EACE,aAAa;AACf;;AAEA;;;;;EAKE,yCAAyC;EACzC,oCAAoC;AACtC;;AAEA;EACE,+CAA+C;AACjD;;AAEA;EACE,yCAAyC;AAC3C;;AAEA;EACE,uCAAuC;AACzC;;AAEA;;EAEE,gBAAgB;EAChB,qCAAqC;AACvC;;AAEA;;;;EAIE,iDAAiD;AACnD;;AAEA;;;;EAIE,sDAAsD;AACxD;;AAEA,SAAS;AACT;EACE,cAAc;AAChB;;AAEA;EACE,eAAe;EACf,iBAAiB;EACjB,yBAAyB;EACzB,qBAAqB;AACvB;;AAEA;EACE,iBAAiB;EACjB,0CAA0C;EAC1C,eAAe;EACf,0CAA0C;EAC1C,8BAA8B;AAChC;;AAEA;EACE,+BAA+B;AACjC;;AAEA;EACE,+BAA+B;EAC/B,gDAAgD;AAClD;;AAEA;EACE,yCAAyC;EACzC,eAAe;EACf,qBAAqB;EACrB,oBAAoB;EACpB,kBAAkB;EAClB,mCAAmC;AACrC;;AAEA;EACE,eAAe;EACf,iBAAiB;EACjB,qBAAqB;EACrB,+BAA+B;EAC/B,kBAAkB;EAClB,YAAY;AACd;;AAEA;EACE,6BAA6B;AAC/B;;AAEA;EACE,aAAa;AACf;;AAEA;EACE,kDAAkD;AACpD;;AAEA;EACE,2CAA2C;AAC7C;;AAEA;EACE,yCAAyC;EACzC,cAAc;EACd,YAAY;EACZ,iBAAiB;EACjB,eAAe;EACf,iBAAiB;AACnB;;AAEA;EACE,YAAY;EACZ,mBAAmB;EACnB,iBAAiB;AACnB;;AAEA;EACE,yCAAyC;AAC3C;;AAEA;EACE,yCAAyC;EACzC,WAAW;EACX,YAAY;EACZ,YAAY;EACZ,iBAAiB;EACjB,aAAa;EACb,mBAAmB;EACnB,uBAAuB;EACvB,2BAA2B;AAC7B;;AAEA;EACE,eAAe;EACf,iBAAiB;EACjB,yCAAyC;EACzC,qBAAqB;EACrB,YAAY;EACZ,iBAAiB;EACjB,eAAe;EACf,iBAAiB;AACnB;;AAEA;EACE,4BAA4B;AAC9B;;AAEA;EACE,qYAAqY;AACvY;;AAEA;EACE,2TAA2T;AAC7T;;AAEA;EACE,WAAW;AACb;;AAEA;EACE,WAAW;AACb;;AAEA;EACE,gBAAgB;AAClB;;AAEA;EACE,ugBAAugB;AACzgB;;AAEA;EACE,2QAA2Q;AAC7Q;;AAEA;EACE,YAAY;EACZ,mBAAmB;AACrB;;AAEA;EACE,WAAW;AACb;;AAEA;EACE,kBAAkB;AACpB;;AAEA;EACE,cAAc;EACd,kBAAkB;EAClB,YAAY;EACZ,YAAY;EACZ,WAAW;EACX,kBAAkB;EAClB,wCAAwC;EACxC,qCAAqC;AACvC;;AAEA,iBAAiB;;AAEjB;EACE,aAAa;AACf;;AAEA;EACE,gBAAgB;EAChB,gBAAgB;EAChB,cAAc;EACd,0CAA0C;EAC1C,kBAAkB;EAClB,2DAA2D;EAC3D,iBAAiB;EACjB,eAAe;EACf;2CACyC;EACzC;wCACsC;AACxC;;AAEA;EACE,kBAAkB;EAClB,MAAM;EACN,OAAO;EACP,WAAW;EACX,YAAY;EACZ,mBAAmB;EACnB,WAAW;EACX,qBAAqB;EACrB,6BAA6B;EAC7B,qBAAqB;EACrB,6BAA6B;AAC/B;;AAEA;EACE,kBAAkB;EAClB,aAAa;EACb,WAAW;EACX,YAAY;EACZ,kBAAkB;EAClB,eAAe;EACf,gBAAgB;EAChB,sBAAsB;EACtB,eAAe;EACf,UAAU;AACZ;;AAEA;EACE,WAAW;;EAEX,8BAA8B;EAC9B,0CAA0C;EAC1C,6BAA6B;EAC7B,kBAAkB;EAClB,MAAM;EACN,OAAO;EACP,QAAQ;EACR,SAAS;EACT,kBAAkB;EAClB,WAAW;AACb;;AAEA;EACE,WAAW;EACX,uCAAuC;EACvC,kBAAkB;EAClB,MAAM;EACN,OAAO;EACP,QAAQ;EACR,SAAS;EACT,kBAAkB;EAClB,WAAW;AACb;;AAEA;EACE,gBAAgB;AAClB;;AAEA;EACE,eAAe;EACf,UAAU;AACZ;;AAEA;;;EAGE,kCAAkC;AACpC;;AAEA;;EAEE,wBAAwB;AAC1B;;AAEA,+EAA+E;AAC/E,gBAAgB;AAChB,+EAA+E;AAC/E;EACE,qCAAqC;AACvC;;AAEA;EACE;qDACmD;EACnD;kDACgD;AAClD;;AAEA;EACE,0BAA0B;AAC5B;;AAEA;EACE,6BAA6B;AAC/B;;AAEA;EACE,2BAA2B,EAAE,eAAe;AAC9C;;AAEA;EACE,yBAAyB;EACzB,aAAa,EAAE,eAAe;AAChC;;AAEA,+EAA+E;AAC/E,eAAe;AACf,+EAA+E;;AAE/E;EACE,kCAAkC;AACpC;;AAEA;EACE;kDACgD;AAClD;;AAEA;EACE,+BAA+B;AACjC;;AAEA;EACE,+BAA+B;AACjC;;AAEA;EACE,iCAAiC,EAAE,eAAe;AACpD;;AAEA;EACE,yBAAyB;EACzB,cAAc,EAAE,eAAe;AACjC;;AAEA;EACE,gBAAgB;EAChB,yBAAyB;EACzB,4BAA4B;EAC5B,YAAY;AACd;;AAEA;EACE,gBAAgB;AAClB;;AAEA;EACE,WAAW;AACb;;AAEA;;EAEE,kBAAkB;AACpB;;AAEA;EACE,gBAAgB;EAChB,mBAAmB;AACrB;;AAEA;;;EAGE,kBAAkB;EAClB,wBAAwB;EACxB,SAAS;EACT,UAAU;AACZ;;AAEA,yDAAyD;AACzD;EACE,SAAS;AACX;;AAEA;EACE,mCAAmC;AACrC;;AAEA;;;EAGE,yCAAyC;AAC3C;;AAEA;;;;EAIE,mCAAmC;AACrC;;AAEA;EACE,aAAa;AACf;;AAEA;;EAEE,UAAU;AACZ;;AAEA;;;;EAIE,yCAAyC;AAC3C;;AAEA;EACE,yCAAyC;EACzC,YAAY;AACd;;AAEA;;EAEE,iBAAiB;EACjB,kBAAkB;AACpB;;AAEA;;EAEE,WAAW;AACb;;AAEA;;EAEE,yCAAyC;AAC3C;;AAEA;;EAEE,yCAAyC;AAC3C;;AAEA;;;EAGE,YAAY;EACZ,aAAa;EACb,mBAAmB;EACnB,gBAAgB;AAClB;;AAEA;;EAEE,yCAAyC;EACzC,oCAAoC;EACpC,YAAY;EACZ,eAAe;AACjB;;AAEA;EACE,kBAAkB;EAClB,mBAAmB;AACrB;;AAEA;EACE,uCAAuC;AACzC;;AAEA;EACE,qBAAqB;AACvB;;AAEA,uBAAuB;AACvB;EACE,sBAAsB;AACxB;;AAEA;EACE,oBAAoB;EACpB,eAAe;AACjB;;AAEA;EACE,cAAc;EACd,kBAAkB;AACpB;;AAEA;EACE,uCAAuC;AACzC;;AAEA;EACE,uCAAuC;AACzC;;AAEA;EACE,qBAAqB;EACrB,sBAAsB;AACxB;;AAEA;EACE,qBAAqB;EACrB,sBAAsB;EACtB,oBAAoB;EACpB,eAAe;EACf,UAAU;EACV,YAAY;EACZ,gBAAgB;EAChB,6BAA6B;AAC/B;;AAEA;EACE,yCAAyC;EACzC,eAAe;AACjB;;AAEA;EACE,4BAA4B;AAC9B","sourcesContent":["/*\n * Copyright 2018-2022 Elyra Authors\n *\n * Licensed under the Apache License, Version 2.0 (the \"License\");\n * you may not use this file except in compliance with the License.\n * You may obtain a copy of the License at\n *\n * http://www.apache.org/licenses/LICENSE-2.0\n *\n * Unless required by applicable law or agreed to in writing, software\n * distributed under the License is distributed on an \"AS IS\" BASIS,\n * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n * See the License for the specific language governing permissions and\n * limitations under the License.\n */\n\nbody {\n  --elyra-border-radius: 0;\n  --elyra-color-icon: var(--jp-icon-contrast-color3);\n  --elyra-color-panel-bg: var(--jp-layout-color1);\n  --elyra-color-panel-border: var(--jp-border-color0);\n\n  --elyra-color-focus: var(--jp-border-color1);\n\n  --elyra-color-text-primary: var(--jp-ui-font-color0);\n\n  --elyra-color-button-text: var(--jp-ui-font-color0);\n  --elyra-color-button-bg: var(--jp-input-active-background);\n  --elyra-color-button-hover-bg: var(--jp-input-hover-background);\n\n  /* ======================================================================== */\n  /* PIPELINE */\n  /* ======================================================================== */\n\n  /* comment */\n  --elyra-color-comment-text: var(--jp-ui-font-color0);\n  --elyra-color-comment-link: var(--jp-border-color1);\n  --elyra-color-comment-bg: var(--jp-editor-selected-background);\n  --elyra-color-comment-border: var(--jp-border-color1);\n\n  /* node */\n  --elyra-color-node-text: var(--jp-ui-font-color0);\n  --elyra-color-node-link: var(--jp-content-link-color);\n  --elyra-color-node-bg: var(--jp-cell-editor-active-background);\n  --elyra-color-node-border: transparent;\n  --elyra-color-node-hover-bg: var(--jp-input-hover-background);\n  --elyra-color-node-hover-border: transparent;\n\n  /* errors */\n  --elyra-color-text-error: var(--jp-rendermime-error-background);\n  --elyra-color-error-border: var(--jp-error-color0);\n\n  /* tooltip */\n  --elyra-color-tooltip-text: var(--jp-content-font-color0);\n  --elyra-color-tooltip-text-bold: var(--jp-editor-selected-background);\n  --elyra-color-tooltip-bg: var(--jp-cell-editor-active-background);\n  --elyra-color-tooltip-border: var(--jp-border-color1);\n\n  /* ======================================================================== */\n  /* FORM */\n  /* ======================================================================== */\n\n  --elyra-color-formLabel-text: var(--jp-content-font-color0);\n  --elyra-color-formDescription-text: var(--jp-content-font-color0);\n\n  /* text input */\n  --elyra-color-textInput-text: var(--jp-content-font-color0);\n  --elyra-color-textInput-bg: var(--jp-cell-editor-active-background);\n  --elyra-color-textInput-border: var(--jp-border-color1);\n  --elyra-color-textInput-disabled-text: var(--jp-inverse-layout-color4);\n\n  /* array input */\n  --elyra-color-arrayInput-text: var(--jp-content-font-color0);\n  --elyra-color-arrayInput-bg: var(--jp-cell-editor-active-background);\n  --elyra-color-arrayInput-border: var(--jp-border-color1);\n\n  /* dropdown */\n  --elyra-color-dropdown-text: var(--jp-content-font-color0);\n  --elyra-color-dropdown-bg: var(--jp-cell-editor-active-background);\n  --elyra-color-dropdown-border: var(--jp-border-color1);\n  --elyra-color-dropdownItem-hover-bg: var(--jp-input-hover-background);\n\n  /* checkbox */\n  --elyra-color-checkbox-text: var(--jp-content-font-color0);\n  --elyra-color-checkbox-bg: var(--jp-cell-editor-active-background);\n  --elyra-color-checkbox-border: var(--jp-border-color1);\n\n  /* primary button */\n  --elyra-color-formButton-text: var(--jp-ui-font-color0);\n  --elyra-color-formButton-bg: var(--jp-layout-color3);\n  --elyra-color-formButton-border: transparent;\n  --elyra-color-formButton-hover-bg: var(--jp-content-font-color3);\n  --elyra-color-formButton-hover-border: transparent;\n\n  /* ======================================================================== */\n  /* PALETTE */\n  /* ======================================================================== */\n  --elyra-color-palette-text: var(--jp-ui-font-color0);\n  --elyra-color-palette-bg: var(--jp-cell-editor-active-background);\n  --elyra-color-palette-border: transparent;\n\n  /* ======================================================================== */\n  /* FONTS */\n  /* ======================================================================== */\n\n  /* sans */\n  --elyra-font-family-sans: var(--jp-ui-font-family);\n  --elyra-font-weight-sans: normal;\n  --elyra-font-size-sans: var(--jp-code-font-size);\n\n  /* mono */\n  --elyra-font-family-mono: var(--jp-ui-font-family);\n  --elyra-font-weight-mono: normal;\n  --elyra-font-size-mono: var(--jp-code-font-size);\n}\n\nbody {\n  background-color: var(--jp-editor-selected-background);\n}\n\n.elyra-empty-text {\n  color: rgba(0, 0, 0, 0.68);\n  cursor: default;\n  font-family: -apple-system, system-ui, sans-serif;\n  font-size: 13px;\n  height: 19px;\n  letter-spacing: 0.52px;\n  line-height: 18.2px;\n  user-select: none;\n}\n\n.elyra-empty-image {\n  opacity: 0.05;\n  margin-bottom: 50px;\n}\n\n.properties-control-panel[data-id='properties-nodeGroupInfo']\n  > .properties-control-panel\n  > .properties-control-item {\n  position: relative;\n}\n\n.properties-control-panel[data-id='properties-nodeGroupInfo']\n  > .properties-control-panel\n  > .properties-control-item\n  .error::before {\n  display: block;\n  content: ' ';\n  position: absolute;\n  width: 6px;\n  border-left-width: 2px;\n  border-left-style: solid;\n  left: 5px;\n  top: 15px;\n  bottom: 18px;\n  border-color: var(--elyra-color-error-border);\n}\n\n.elyra-stringArrayControl-inputWrapper {\n  height: 35px;\n}\n\n.elyra-PipelineEditor .elyra-stringArrayControl-input {\n  width: 100%;\n  height: 100%;\n  margin-bottom: 5px;\n}\n\n.properties-input-control.error input:not([disabled]) {\n  box-shadow: none;\n}\n\nspan.bx--list-box__label {\n  color: var(--elyra-color-formLabel-text);\n}\n\n.properties-dropdown.error .bx--list-box__field:not([disabled]) {\n  box-shadow: none;\n}\n\n.elyra-PipelineEditor .properties-wrapper .bx--list-box__field {\n  height: 100%;\n}\n\n.elyra-PipelineEditor .properties-wrapper input[type='text']:disabled {\n  height: 39px;\n  padding-left: 8px;\n}\n\n.properties-dropdown .bx--list-box--expanded .bx--list-box__menu {\n  top: auto;\n}\n\n.properties-wrapper .bx--list-box__menu-item {\n  display: contents;\n}\n\n.properties-required-indicator {\n  display: none;\n}\n\n.properties-control-panel[data-id='properties-elyra_resources']\n  .properties-custom-ctrl {\n  position: absolute;\n  bottom: 18px;\n  padding-right: 14px;\n}\n\n.properties-control-panel[data-id='properties-elyra_resources']\n  .properties-control-description {\n  padding-bottom: 35px;\n}\n\n.elyra-stringArrayControl-listItem {\n  padding: 5px;\n}\n\n.elyra-stringArrayControl-listRow:hover {\n  position: relative;\n  background-color: var(--jp-border-color2);\n}\n\n/* ======================================================== */\n/* ======================================================== */\n/* ======================================================== */\n\n.properties-control-panel[data-id='properties-nodeGroupInfo']\n  > .properties-control-panel\n  > .properties-control-item {\n  position: relative;\n}\n\n.properties-control-panel[data-id='properties-nodeGroupInfo']\n  > .properties-control-panel\n  > .properties-control-item:hover {\n  background-color: var(--jp-cell-editor-background);\n}\n\n.properties-control-panel[data-id='properties-nodeGroupInfo']\n  > .properties-control-panel\n  > .properties-control-item.selected {\n  background-color: var(--jp-editor-selected-focused-background);\n}\n\n.properties-control-panel[data-id='properties-nodeGroupInfo']\n  > .properties-control-panel\n  > .properties-control-item.selected::before {\n  content: '';\n  position: absolute;\n  top: 0;\n  left: 0;\n  right: 0;\n  border-top: 1px solid var(--jp-border-color2);\n}\n\n.elyra-stringArrayControl-listRow {\n  background-color: var(--jp-border-color3);\n  margin-bottom: 5px;\n}\n\n.properties-control-panel[data-id='properties-nodeGroupInfo']\n  > .properties-control-panel\n  > .properties-control-item.selected::after {\n  content: '';\n  position: absolute;\n  bottom: 0;\n  left: 0;\n  right: 0;\n  border-top: 1px solid var(--jp-border-color2);\n}\n\n.elyra-resourcesWrapper {\n  display: flex;\n  flex-direction: row;\n  position: relative;\n  height: 110px;\n}\n\n.elyra-resourceInput {\n  width: 22%;\n  display: flex;\n  flex-direction: column;\n  padding-right: 9px;\n}\n/* ======================================================== */\n/* ======================================================== */\n/* ======================================================== */\n\n.d3-node-port-input,\n.d3-node-port-output,\n.d3-node-port-input[connected='yes'],\n.d3-node-port-output[connected='yes'] {\n  stroke: var(--elyra-color-comment-text);\n  fill: var(--elyra-color-comment-text);\n  stroke-width: 4;\n}\n\n.d3-node-port-input:hover,\n.d3-node-port-output:hover,\n.d3-node-port-input[connected='yes']:hover,\n.d3-node-port-output[connected='yes']:hover {\n  stroke: var(--elyra-color-node-text);\n  fill: var(--elyra-color-node-text);\n  stroke-width: 4;\n}\n\n.d3-node-port-input-arrow {\n  display: none;\n}\n\n.elyra-PipelineEditor .palette-flyout-div,\n.elyra-PipelineEditor\n  .palette-flyout-search-container\n  .palette-flyout-search\n  input {\n  background-color: var(--jp-layout-color1);\n  color: var(--jp-content-font-color1);\n}\n\n.elyra-PipelineEditor .palette-flyout-div {\n  border-right: 1px solid var(--jp-layout-color3);\n}\n\n.elyra-PipelineEditor .palette-flyout-content .palette-list-item:hover {\n  background-color: var(--jp-border-color1);\n}\n\n.elyra-PipelineEditor .bx--search-magnifier {\n  stroke: var(--jp-inverse-layout-color1);\n}\n\n.elyra-PipelineEditor svg.palette-flyout-category-caret,\n.elyra-PipelineEditor .palette-flyout-category-item-icon {\n  background: none;\n  fill: var(--jp-inverse-layout-color1);\n}\n\n.tip-palette-item,\n.tip-palette-category,\n.tip-palette-label,\n.tip-palette-desc {\n  color: var(--elyra-color-tooltip-text) !important;\n}\n\n.elyra-PipelineEditor\n  .palette-flyout-category\n  .elyra-PipelineEditor\n  .palette-content-list {\n  border-bottom: 1px solid var(--jp-content-font-color0);\n}\n\n/* tabs */\n.elyra-tabPanel > .elyra-actionBar {\n  padding: 0 8px;\n}\n\n.elyra-tab {\n  cursor: pointer;\n  user-select: none;\n  text-transform: uppercase;\n  padding: 4px 10px 3px;\n}\n\n.elyra-tabText {\n  line-height: 27px;\n  font-family: var(--elyra-font-family-sans);\n  font-size: 11px;\n  font-weight: var(--elyra-font-weight-sans);\n  color: var(--jp-border-color1);\n}\n\n.elyra-tabText:hover {\n  color: var(--jp-ui-font-color0);\n}\n\n.elyra-tabText.activeTab {\n  color: var(--jp-ui-font-color0);\n  border-bottom: 1px solid var(--jp-border-color2);\n}\n\n.elyra-icon {\n  font: normal normal normal 16px/1 codicon;\n  font-size: 16px;\n  text-decoration: none;\n  text-rendering: auto;\n  text-align: center;\n  -webkit-font-smoothing: antialiased;\n}\n\n.elyra-actionItem {\n  cursor: pointer;\n  user-select: none;\n  display: inline-block;\n  transition: transform 50ms ease;\n  position: relative;\n  padding: 3px;\n}\n\n.elyra-actionItem:active {\n  transform: scale(1.272019649);\n}\n\n.elyra-verticalTabGroup .elyra-tabItem {\n  margin: 3px 0;\n}\n\n.elyra-verticalTabGroup .elyra-tabItem:hover {\n  background-color: var(--jp-cell-editor-background);\n}\n\n.elyra-verticalTabGroup .elyra-tabItem:active {\n  background-color: rgba(255, 255, 255, 0.18);\n}\n\n.elyra-actionBar .elyra-actionItemIcon {\n  color: var(--elyra-color-arrayInput-text);\n  display: block;\n  height: 35px;\n  line-height: 35px;\n  min-width: 28px;\n  margin-right: 4px;\n}\n\n.elyra-stringArrayControl-listRow:hover .elyra-stringArrayControl-listActions {\n  height: 100%;\n  align-items: center;\n  margin-right: 3px;\n}\n\n.elyra-actionItem:hover {\n  background-color: var(--jp-border-color1);\n}\n\n.elyra-stringArrayControl-listActions .elyra-actionItemIcon {\n  color: var(--elyra-color-arrayInput-text);\n  width: 16px;\n  height: 20px;\n  padding: 2px;\n  margin-right: 2px;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  background-position: center;\n}\n\n.elyra-tabItemIcon {\n  cursor: pointer;\n  user-select: none;\n  color: var(--elyra-color-arrayInput-text);\n  display: inline-block;\n  height: 35px;\n  line-height: 35px;\n  min-width: 28px;\n  margin-right: 4px;\n}\n\n.elyra-icon {\n  background-repeat: no-repeat;\n}\n\n.elyra-icon.elyra-item-delete {\n  background-image: url('data:image/svg+xml;utf8,<svg focusable=\"false\" preserveAspectRatio=\"xMidYMid meet\" xmlns=\"http://www.w3.org/2000/svg\" width=\"15\" height=\"32\" viewBox=\"0 0 32 32\"> <title>Delete item</title> <g class=\"jp-icon3\"> <path d=\"M12 12H14V24H12zM18 12H20V24H18z\"></path> <path d=\"M4 6V8H6V28a2 2 0 002 2H24a2 2 0 002-2V8h2V6zM8 28V8H24V28zM12 2H20V4H12z\"></path> </g> </svg>');\n}\n\n.elyra-icon.elyra-item-edit {\n  background-image: url('data:image/svg+xml;utf8,<svg viewBox=\"0 0 24 24\" width=\"16\" xmlns=\"http://www.w3.org/2000/svg\"> <g class=\"jp-icon3\"> <path d=\"M3 17.25V21h3.75L17.81 9.94l-3.75-3.75L3 17.25zM20.71 7.04c.39-.39.39-1.02 0-1.41l-2.34-2.34c-.39-.39-1.02-.39-1.41 0l-1.83 1.83 3.75 3.75 1.83-1.83z\"/> </g> </svg>');\n}\n\n.elyra-icon.elyra-panel-close::before {\n  content: '';\n}\n\n.elyra-icon.properties::before {\n  content: '';\n}\n\n.elyra-icon.palette::before {\n  content: '\\eb5c';\n}\n\n.elyra-icon.properties-checkbox {\n  background-image: url('data:image/svg+xml;utf8,<svg viewBox=\"0 0 24 24\" width=\"16\" xmlns=\"http://www.w3.org/2000/svg\"> <g class=\"jp-icon-none jp-icon-selectable-inverse jp-icon3-hover\" fill=\"none\"> <circle cx=\"12\" cy=\"12\" r=\"11\"/></g><g class=\"jp-icon3 jp-icon-selectable jp-icon-accent2-hover\" fill=\"#616161\"><path d=\"M19 6.41L17.59 5 12 10.59 6.41 5 5 6.41 10.59 12 5 17.59 6.41 19 12 13.41 17.59 19 19 17.59 13.41 12z\"/></g><g class=\"jp-icon-none jp-icon-busy\" fill=\"none\"><circle cx=\"12\" cy=\"12\" r=\"7\"/></g></svg>');\n}\n\n.elyra-icon.elyra-item-folder {\n  background-image: url('data:image/svg+xml;utf8,<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 24 24\"> <path class=\"jp-icon3 jp-icon-selectable\" d=\"M10 4H4c-1.1 0-1.99.9-1.99 2L2 18c0 1.1.9 2 2 2h16c1.1 0 2-.9 2-2V8c0-1.1-.9-2-2-2h-8l-2-2z\"/> </svg>');\n}\n\n.elyra-stringArrayActions {\n  height: 100%;\n  align-items: center;\n}\n\n.elyra-inputContainer {\n  width: 100%;\n}\n\n.elyra-listRow {\n  margin-bottom: 3px;\n}\n\n.elyra-loader {\n  display: block;\n  position: absolute;\n  left: -200px;\n  width: 200px;\n  height: 4px;\n  border-radius: 4px;\n  background-color: var(--jp-brand-color1);\n  animation: loading 2s linear infinite;\n}\n\n/* context menu */\n\n.d3-node-ellipsis-group {\n  display: none;\n}\n\n.context-menu-popover {\n  margin-top: -6px;\n  margin-left: 2px;\n  padding: 6px 0;\n  backdrop-filter: saturate(180%) blur(20px);\n  border-radius: 6px;\n  /* box-shadow: 0px 4px 17.64px 3.36px rgba(0, 0, 0, 0.2); */\n  user-select: none;\n  cursor: default;\n  /* box-shadow: 0px 2px 4px 0px rgba(0, 0, 0, 0.05),\n    0px 8px 15px 2px rgba(0, 0, 0, 0.18); */\n  box-shadow: 0px 1px 2px 0px rgba(0, 0, 0, 0.05),\n    0px 4px 15px 2px rgba(0, 0, 0, 0.18);\n}\n\n.context-menu-popover::before {\n  position: absolute;\n  top: 0;\n  left: 0;\n  width: 200%;\n  height: 200%;\n  border-radius: 13px;\n  content: '';\n  transform: scale(0.5);\n  -webkit-transform: scale(0.5);\n  transform-origin: 0 0;\n  -webkit-transform-origin: 0 0;\n}\n\n.react-contextmenu-item {\n  position: relative;\n  margin: 0 6px;\n  width: auto;\n  height: 22px;\n  border-radius: 4px;\n  font-size: 13px;\n  padding: 3px 9px;\n  box-sizing: border-box;\n  cursor: default;\n  z-index: 0;\n}\n\n.react-contextmenu-item:hover::before {\n  content: '';\n\n  /* rgba(10, 130, 255, 0.75); */\n  background-color: rgba(54, 131, 247, 0.75);\n  backdrop-filter: saturate(0%);\n  position: absolute;\n  top: 0;\n  left: 0;\n  right: 0;\n  bottom: 0;\n  border-radius: 4px;\n  z-index: -1;\n}\n\n.react-contextmenu-item:hover::after {\n  content: '';\n  background: var(--elyra-color-panel-bg);\n  position: absolute;\n  top: 0;\n  left: 0;\n  right: 0;\n  bottom: 0;\n  border-radius: 4px;\n  z-index: -2;\n}\n\n.react-contextmenu-item.contextmenu-divider {\n  margin: 5px 15px;\n}\n\n.react-contextmenu-item.react-contextmenu-item--disabled {\n  cursor: default;\n  opacity: 1;\n}\n\n.react-contextmenu-item:active,\n.react-contextmenu-item:focus,\n.react-contextmenu-item.react-contextmenu-item--disabled {\n  background: transparent !important;\n}\n\n.react-contextmenu-item.react-contextmenu-item--disabled::before,\n.react-contextmenu-item.react-contextmenu-item--disabled::after {\n  display: none !important;\n}\n\n/* ========================================================================== */\n/* LIGHT THEME */\n/* ========================================================================== */\n.context-menu-popover {\n  background: rgba(231, 231, 231, 0.76);\n}\n\n.context-menu-popover::before {\n  /* box-shadow: inset 0px 0px 0px 1px rgba(0, 0, 0, 0.22),\n    inset 0px 0px 0px 2px rgba(255, 255, 255, 0.1); */\n  box-shadow: 0px 0px 0px 1px rgba(0, 0, 0, 0.22),\n    inset 0px 0px 0px 1px rgba(255, 255, 255, 0.1);\n}\n\n.react-contextmenu-item {\n  color: rgba(0, 0, 0, 0.85);\n}\n\n.react-contextmenu-item:hover {\n  color: rgba(255, 255, 255, 1);\n}\n\n.react-contextmenu-item.react-contextmenu-item--disabled {\n  color: rgba(0, 0, 0, 0.315); /* 0.27, 0.36 */\n}\n\n.react-contextmenu-item.contextmenu-divider {\n  background-color: #000000;\n  opacity: 0.13; /* 0.11, 0.15 */\n}\n\n/* ========================================================================== */\n/* DARK THEME */\n/* ========================================================================== */\n\nbody.elyra-dark .context-menu-popover {\n  background: rgba(46, 46, 46, 0.72);\n}\n\nbody.elyra-dark .context-menu-popover::before {\n  box-shadow: inset 0px 0px 0px 1px rgba(0, 0, 0, 0.86),\n    inset 0px 0px 0px 3px rgba(255, 255, 255, 0.2);\n}\n\nbody.elyra-dark .react-contextmenu-item {\n  color: rgba(255, 255, 255, 0.9);\n}\n\nbody.elyra-dark .react-contextmenu-item:hover {\n  color: rgba(255, 255, 255, 0.9);\n}\n\nbody.elyra-dark .react-contextmenu-item.react-contextmenu-item--disabled {\n  color: rgba(255, 255, 255, 0.355); /* 0.29, 0.42 */\n}\n\nbody.elyra-dark .react-contextmenu-item.contextmenu-divider {\n  background-color: #ffffff;\n  opacity: 0.205; /* 0.17, 0.24 */\n}\n\ninput.elyra-Dialog-checkbox.jp-mod-styled {\n  appearance: auto;\n  -moz-appearance: checkbox;\n  -webkit-appearance: checkbox;\n  height: auto;\n}\n\n.elyra-dialog-form {\n  max-width: 700px;\n}\n\n.elyra-dialog-form input[type='text'] {\n  width: 100%;\n}\n\n.elyra-dialog-form input,\n.elyra-dialog-form select.jp-mod-styled {\n  border-radius: 4px;\n}\n\n.elyra-resourceInputDescription {\n  padding-top: 4px;\n  padding-bottom: 4px;\n}\n\n#cpu,\n#gpu,\n#memory {\n  position: absolute;\n  vertical-align: baseline;\n  bottom: 0;\n  width: 20%;\n}\n\n/* fix a Safari bug where button margins default to 2px */\n.properties-control-panel button {\n  margin: 0;\n}\n\n.toolbar-item-content .toolbar-icon svg {\n  background: var(--jp-border-color2);\n}\n\n.elyra-PipelineEditor .toolbar-item.default button:disabled:hover svg,\n.toolbar-item.ghost button:disabled:hover svg,\n.toolbar-overflow-menu-item button:disabled:hover svg {\n  background-color: var(--jp-border-color2);\n}\n\n.elyra-PipelineEditor .toolbar-item.default button:hover svg,\n.toolbar-item.ghost button:hover svg,\n.toolbar-overflow-item button:hover svg,\n.toolbar-overflow-menu-item button:hover svg {\n  background: var(--jp-border-color1);\n}\n\n.properties-control-panel[data-id='properties-elyra_resources'] {\n  display: flex;\n}\n\n.properties-control-panel[data-id='properties-elyra_resources']\n  .properties-ctrl-wrapper {\n  width: 33%;\n}\n\n.elyra-PipelineEditor .toolbar-item.default button:hover,\n.toolbar-item.ghost button:hover,\n.toolbar-overflow-item button:hover,\n.toolbar-overflow-menu-item button:hover {\n  background-color: var(--jp-border-color1);\n}\n\n.properties-custom-ctrl div[data-testid='list-row'] {\n  background-color: var(--jp-border-color1);\n  padding: 3px;\n}\n\n.properties-control-item[data-id='properties-ci-runtime_image']\n  ul[role='listbox'] {\n  max-height: 120px;\n  overflow-y: scroll;\n}\n\n.properties-control-item[data-id='properties-ci-runtime_image']\n  ul[role='listbox']::-webkit-scrollbar {\n  width: 10px;\n}\n\n.properties-control-item[data-id='properties-ci-runtime_image']\n  ul[role='listbox']::-webkit-scrollbar-thumb {\n  background-color: var(--jp-border-color1);\n}\n\n.properties-control-item[data-id='properties-ci-runtime_image']\n  ul[role='listbox']::-webkit-scrollbar-thumb:hover {\n  background-color: var(--jp-border-color0);\n}\n\n.properties-control-item[data-id='properties-ci-runtime_image']\n  ul[role='listbox']\n  li {\n  height: 22px;\n  display: flex;\n  align-items: center;\n  margin-left: 5px;\n}\n\n.elyra-PipelineEditor .toolbar-item.tertiary button:disabled,\n.elyra-PipelineEditor .toolbar-item.tertiary button:disabled:hover {\n  background-color: var(--jp-border-color2);\n  color: var(--jp-content-font-color1);\n  border: none;\n  cursor: initial;\n}\n\n.elyra-PipelineEditor .elyra_categoryHeader {\n  padding-left: 33px;\n  padding-right: 24px;\n}\n\n.elyra-PipelineEditor .elyra_categoryHeader .panel-label {\n  font-size: var(--jp-content-font-size2);\n}\n\n.elyra-PipelineEditor-Alert {\n  white-space: pre-line;\n}\n\n/* fix font ligatures */\n.lsp-completer-theme-vscode {\n  letter-spacing: normal;\n}\n\na {\n  pointer-events: auto;\n  cursor: pointer;\n}\n\n.empty-pipeline-header {\n  color: #8897a2;\n  text-align: center;\n}\n\nh3.empty-pipeline-header {\n  font-size: var(--jp-content-font-size5);\n}\n\nh4.empty-pipeline-header {\n  font-size: var(--jp-content-font-size3);\n}\n\n.empty-pipeline-icon {\n  display: inline-block;\n  vertical-align: middle;\n}\n\n.empty-pipeline-button {\n  display: inline-block;\n  vertical-align: middle;\n  pointer-events: auto;\n  cursor: pointer;\n  padding: 0;\n  border: none;\n  background: none;\n  color: var(--jp-brand-color1);\n}\n\n.empty-pipeline-button:hover {\n  background-color: var(--jp-layout-color2);\n  cursor: pointer;\n}\n\n.empty-pipeline-button .jp-icon3[fill] {\n  fill: var(--jp-brand-color1);\n}\n"],"sourceRoot":""}]);
// Exports
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (___CSS_LOADER_EXPORT___);


/***/ }),

/***/ "./style/index.css":
/*!*************************!*\
  !*** ./style/index.css ***!
  \*************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _node_modules_style_loader_dist_runtime_injectStylesIntoStyleTag_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! !../../../node_modules/style-loader/dist/runtime/injectStylesIntoStyleTag.js */ "../../node_modules/style-loader/dist/runtime/injectStylesIntoStyleTag.js");
/* harmony import */ var _node_modules_style_loader_dist_runtime_injectStylesIntoStyleTag_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_node_modules_style_loader_dist_runtime_injectStylesIntoStyleTag_js__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _node_modules_css_loader_dist_cjs_js_index_css__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! !!../../../node_modules/css-loader/dist/cjs.js!./index.css */ "../../node_modules/css-loader/dist/cjs.js!./style/index.css");

            

var options = {};

options.insert = "head";
options.singleton = false;

var update = _node_modules_style_loader_dist_runtime_injectStylesIntoStyleTag_js__WEBPACK_IMPORTED_MODULE_0___default()(_node_modules_css_loader_dist_cjs_js_index_css__WEBPACK_IMPORTED_MODULE_1__["default"], options);



/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (_node_modules_css_loader_dist_cjs_js_index_css__WEBPACK_IMPORTED_MODULE_1__["default"].locals || {});

/***/ })

}]);
//# sourceMappingURL=style_index_css.2b8dca0ee13138a3f2fb.js.map